/*
 *  mesh.h
 *
 *  Copyright 2007-2010 Jon Robey and Bob Robey, brobey@lanl.gov 
 *  All rights reserved.
 *  Los Alamos National Laboratory and Supercomputing Challenge
 *  Permission granted for use in Supercomputing Challenge Projects
 */

#ifndef MESH_H_
#define MESH_H_

#define SLOPED_WAVE  1
#define WAVE_BOX     2

void mesh_set_size(unsigned int imax, unsigned int jmax);
unsigned int mesh_get_mysize(void);
unsigned int mesh_get_myoffset(void);

void mesh_initialize(unsigned int problem, double **H, double **U, double **V);
double mesh_get_deltaX(void);
double mesh_get_deltaY(void);
double mesh_get_xmin(void);
double mesh_get_ymin(void);
double mesh_get_xmax(void);
double mesh_get_ymax(void);
double *mesh_get_x(void);
double *mesh_get_y(void);
double *mesh_get_dx(void);
double *mesh_get_dy(void);


void mesh_set_boundary_conditions(double **H, double **U, double **V);

double mesh_set_timestep(double g, double sigma, double **H, double **U, double **V);

void mesh_output(char *title, unsigned int imin, unsigned int imax, unsigned int jmin, unsigned int jmax,
    double **H, double **U, double **V);

void cycle_print(double **display_var, unsigned int n, unsigned int icount, double time,
    double deltaT, double TotalMass, double **mesh_var, double colorScale,
    double graphScale, unsigned int meshRow, char *label);
void sum_init(void);
void sum_finalize(void);
double sum_var(double **var);
void mesh_set_plot_var(double **mesh_var, double **plot_var);

#endif /* MESH_H_ */
